Module dfx_base::parser

source ·

Structs

Enums

Functions

  • Returns Option<(pos, len)> if it can find the length in the fix message otherwise returns None.
  • Returns Some<String> if it can find a potential fix message otherwise returns None Drains the buffer.